import {
  ChangeDetectionStrategy,
  Component,
  inject,
  OnDestroy,
  OnInit,
  signal,
} from '@angular/core';
import { RouterModule } from '@angular/router';
import { AuthService } from '@service/auth.service';
import { Subscription } from 'rxjs';
import { AnimatedNumberComponent } from '@blackjack/components/animated-number/animated-number.component';
import { UserService } from '@service/user.service';

@Component({
  selector: 'app-navbar',
  templateUrl: './navbar.component.html',
  standalone: true,
  imports: [RouterModule, AnimatedNumberComponent],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class NavbarComponent implements OnInit, OnDestroy {
  isMenuOpen = false;
  private authService: AuthService = inject(AuthService);
  private userService: UserService = inject(UserService);
  isLoggedIn = this.authService.isLoggedIn();

  private authSubscription!: Subscription;
  private userSubscription!: Subscription;
  public balance = signal(0);

  ngOnInit() {
    this.authSubscription = this.authService.userSubject.subscribe({
      next: (user) => {
        this.balance.set(user?.balance ?? 0);
      },
    });

    // Also subscribe to UserService for real-time balance updates
    this.userSubscription = this.userService.currentUser$.subscribe({
      next: (user) => {
        if (user) {
          this.balance.set(user.balance);
        }
      },
    });
  }

  ngOnDestroy() {
    this.authSubscription.unsubscribe();
    if (this.userSubscription) {
      this.userSubscription.unsubscribe();
    }
  }

  logout() {
    this.authService.logout();
  }

  toggleMenu() {
    this.isMenuOpen = !this.isMenuOpen;
  }
}
